@@ -195,12 +195,12 @@ fr_command_ar_list (FrCommand *comm)
 
 
 static void
-fr_command_ar_add (FrCommand     *comm,
-		   const char    *from_file,
-		   GList         *file_list,
-		   const char    *base_dir,
-		   gboolean       update,
-		   gboolean       recursive)
+fr_command_ar_add (FrCommand  *comm,
+		   const char *from_file,
+		   GList      *file_list,
+		   const char *base_dir,
+		   gboolean    update,
+		   gboolean    follow_links)
 {
 	GList *scan;
 
@@ -355,6 +355,7 @@ fr_command_ar_init (FrCommandAr *self)
 	base->propAddCanUpdate             = TRUE;
 	base->propAddCanReplace            = TRUE;
 	base->propAddCanStoreFolders       = FALSE;
+	base->propAddCanStoreLinks         = FALSE;
 	base->propExtractCanAvoidOverwrite = FALSE;
 	base->propExtractCanSkipOlder      = FALSE;
 	base->propExtractCanJunkPaths      = FALSE;
